@@ -39,7 +39,7 @@ struct Metrics {
 
     // frames
     static constexpr int Frame_FrameWidth = 2;
-    static constexpr int Frame_FrameRadius = 3;
+    static constexpr int Frame_FrameRadius = 5;
 
     // layout
     static constexpr int Layout_TopLevelMarginWidth = 10;
@@ -107,6 +107,7 @@ struct Metrics {
     static constexpr int ToolBar_ExtensionWidth = 20;
     static constexpr int ToolBar_ItemMargin = 6;
     static constexpr int ToolBar_ItemSpacing = 0;
+    static constexpr int ToolBar_SeparatorVerticalMargin = 2;
 
     // progressbars
     static constexpr int ProgressBar_BusyIndicatorSize = 14;
@@ -130,6 +131,7 @@ struct Metrics {
     static constexpr int TabBar_TabItemSpacing = 8;
     static constexpr int TabBar_TabOverlap = 1;
     static constexpr int TabBar_BaseOverlap = 2;
+    static constexpr int TabBar_ActiveEffectSize = 3;
 
     // tab widget
     static constexpr int TabWidget_MarginWidth = 3;
@@ -159,6 +161,8 @@ struct Metrics {
     static constexpr int Shadow_Overlap = 2;
 
     // frame intensities (called bias in KColorUtilities::Mix)
-    static constexpr qreal Bias_Default = 0.25;
+    // Keep this value in sync with Kirigami  PlatformTheme::frameContrast()
+    // https://invent.kde.org/frameworks/kirigami/-/blob/master/src/platform/platformtheme.cpp?ref_type=heads#L701
+    static constexpr qreal Bias_Default = 0.20;
 };
 }
